@@ -19,6 +19,8 @@ watershed
 imread/imsave
     read/write image
 
+Documentation: http://mahotas.readthedocs.org/
+
 Citation:
 
     Coelho, Luis Pedro, 2013. Mahotas: Open source software for scriptable
@@ -36,10 +38,11 @@ try:
                             rank_filter, \
                             template_match, \
                             gaussian_filter1d, \
-                            gaussian_filter
+                            gaussian_filter, \
+                            laplacian_2D
     from .convolve import haar, ihaar, daubechies, idaubechies, wavelet_center, wavelet_decenter
     from .distance import distance
-    from .edge import sobel
+    from .edge import sobel, dog
     from .euler import euler
     from .histogram import fullhistogram
     from .labeled import border, borders, bwperim, label, labeled_sum
@@ -133,15 +136,19 @@ __all__ = [
     'cerode',
     'close',
     'close_holes',
+    'colors',
     'convolve',
     'convolve1d',
     'croptobbox',
     'cwatershed',
     'daubechies',
     'dilate',
+    'disk',
     'distance',
+    'dog',
     'erode',
     'euler',
+    'find',
     'fullhistogram',
     'gaussian_filter',
     'gaussian_filter1d',
@@ -155,6 +162,7 @@ __all__ = [
     'imsave',
     'label',
     'labeled_sum',
+    'laplacian_2D',
     'locmax',
     'locmin',
     'majority_filter',
@@ -163,12 +171,14 @@ __all__ = [
     'moments',
     'open',
     'otsu',
+    'overlay',
     'rank_filter',
     'rc',
     'regmax',
     'regmin',
     'sobel',
     'stretch',
+    'stretch_rgb',
     'template_match',
     'thin',
     'wavelet_center',
@@ -183,7 +193,7 @@ __all__ = [
     'test',
 
     'citation',
-    'citation_text'
+    'citation_text',
     '__version__',
     ]
 
